@@ -122,7 +122,7 @@ class mysql(object):
 	def __init__(self, host='127.0.0.1',**args):
 		import pymysql
 		self.pymysql=pymysql
-		connect_config={'host':host,'user':'root','password':'','db':'localhost','charset':'utf8','cursorclass':pymysql.cursors.DictCursor}
+		connect_config={'host':host,'user':'root','password':'','db':'localhost','charset':'utf8','cursorclass':pymysql.cursors.DictCursor,'autocommit':None}
 		if 'table' in args:
 			self.table=args['table']
 			del args['table']
@@ -174,9 +174,9 @@ class mysql(object):
 		strs=strs.strip()
 		is_query = True if strs[:4].lower() in ['sele','show'] else False
 		with self.conn.cursor() as cur:
-			data=cur.execute(strs)
+			cur.execute(strs)
 			data=cur.fetchall() if is_query else cur.lastrowid
-		is_query or self.conn.commit()
+		# is_query or self.conn.commit()
 		return data
 	def add(self,dicts,table=None,ignore=False):
 		'''table is optional,dicts can be list or dict'''
